@@ -1,10 +1,11 @@
 from pysite.exceptions.conf import *
 import imp
-from os.path import abspath,dirname,join
+from os.path import abspath,dirname,join,normpath
 
 class PySiteConfiguration(object):
 	def __init__(self,basedir,sitename=None,sitetitle=None,logfile=None):
 		self.basedir = basedir
+		self.basedir_a = abspath(normpath(basedir))
 		if sitename:
 			self.sitename = sitename
 			
@@ -21,6 +22,14 @@ class PySiteConfiguration(object):
 		elif not getattr(self,'logfile',None):
 			self.logfile = join(self.basedir,'%s.log' % self.sitename)
 
+	def basedir_abspath(self):
+		"""
+		Get the absolute path to the site base directory
+		
+		@rtype: string
+		"""
+		return self.basedir_a
+
 global_conf = None
 
 def getConfiguration(basedir=None):
@@ -28,4 +37,6 @@ def getConfiguration(basedir=None):
 	if not global_conf:
 		confmod = imp.load_source('conf',join(basedir,'conf.py'))
 		global_conf = confmod.siteconf(basedir)
-	return global_conf
\ No newline at end of file
+	return global_conf
+
+get_conf = getConfiguration
\ No newline at end of file
