@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 import re,sys
+from pysite.compat import PORTABLE_STRING,PORTABLE_BYTES
 
 if sys.version_info[0]==2:
 	from urllib2 import unquote
@@ -8,20 +9,23 @@ elif sys.version_info[0]>=3:
 
 class HTTPRequestData(object):
 	def __init__(self,post_values,query_string,cookies):
+		if type(post_values)==PORTABLE_BYTES:
+			post_values = PORTABLE_STRING(post_values,'utf-8')
+		if type(query_string)==PORTABLE_BYTES:
+			query_string = PORTABLE_STRING(query_string,'utf-8')
+		if type(cookies)==PORTABLE_BYTES:
+			cookies = PORTABLE_STRING(cookies,'utf-8')
 		self.post_values = unquote(post_values.replace('+',' '))
 		self.query_string = unquote(query_string.replace('+',' '))
 		self.cookies = unquote(cookies.replace('+',' '))
 		
 	# Probe function
 	@staticmethod
-	def _probe_value(data,varname,encoding='utf-8'):
+	def _probe_value(data,varname):
 		rx = re.compile('%s=([^&]+)' % varname)
-		miter = rx.finditer(data)
-		try:
-			match = miter.next()
-			return unicode(match.groups()[0],encoding)
-		except StopIteration:
-			return None
+		for match in rx.finditer(data):
+			return match.group(1)
+		return None
 	
 	def get_post_value(self,varname):
 		return HTTPRequestData._probe_value(self.post_values,varname)
