@@ -6,7 +6,15 @@ import os,re,pprint
 import imp,ast,sys
 import xml.dom.minidom as minidom
 from os.path import relpath,dirname
-from pysite.compat import PORTABLE_STRING
+from pysite.compat import PORTABLE_STRING,portable_string
+from slimit.parser import Parser
+from slimit.visitors import nodevisitor
+from slimit import ast as jsast
+
+rx_rmquotes = re.compile(u'^["\'](.+)["\']$')
+
+parser = Parser()
+
 
 if sys.version_info[0]==2:
 	arg_name_attr = 'id'
@@ -31,6 +39,8 @@ def update_transdict(context,source,filename,lineno,comment=''):
 def parse_subhandler(context):
 	translate_args = ['source','context','comment','lang']
 	fname = PORTABLE_STRING('subhandlers/%s.py' % context)
+	sys.stdout.write(u"Parsing: %s... " % fname)
+	transcnt = 0
 	a = ast.parse(open(fname).read())
 	encoding = 'utf-8'
 	for obj in a.body:
@@ -39,7 +49,10 @@ def parse_subhandler(context):
 			for n in ast.walk(obj):
 				if isinstance(n,ast.Call) and isinstance(n.func,ast.Name) and n.func.id==translator_id:
 					acnt = 0
-					args = {'source':None,'context':context,'comment':PORTABLE_STRING('')}
+					args = {
+						'source':None,
+						'context':context if type(context)==PORTABLE_STRING else PORTABLE_STRING(context,encoding),
+						'comment':PORTABLE_STRING('')}
 					for arg in n.args:
 						if isinstance(arg,ast.Str):
 							args[translate_args[acnt]] = arg.s if type(arg.s)==PORTABLE_STRING else PORTABLE_STRING(arg.s,encoding)
@@ -47,13 +60,18 @@ def parse_subhandler(context):
 					for kwarg in n.keywords:
 						args[kwarg.arg] = kwarg.value.s if type(kwarg.value.s)==PORTABLE_STRING else PORTABLE_STRING(kwarg.value.s,encoding)
 					update_transdict(args['context'],args['source'],fname,n.lineno,args['comment'])
+					transcnt += 1
+	print(u'Found %d translations' % transcnt)
 
 def parse_jinja_template(context):
 	translate_args = ['source','context','comment','lang']
 	e = Environment()
 	fname = PORTABLE_STRING('templates/%s.jinja' % context)
+	sys.stdout.write(u"Parsing: %s... " % fname)
 	stream = open(fname,'rb')
-	t = e.parse(PORTABLE_STRING(stream.read(),'utf-8'))
+	encoding = 'utf-8'
+	transcnt = 0
+	t = e.parse(PORTABLE_STRING(stream.read(),encoding))
 	for it in t.find_all(Getitem):
 		if isinstance(it.node,Name) and it.node.name=='tr' and isinstance(it.arg,Const):
 			update_transdict(context,it.arg.value,fname,it.node.lineno)
@@ -69,27 +87,73 @@ def parse_jinja_template(context):
 	for it in t.find_all(Call):
 		if isinstance(it.node,Name) and it.node.name=='translate':
 			acnt = 0
-			args = {'source':None,'context':context,'comment':''}
+			args = {
+				'source':None,
+				'context':portable_string(context,encoding),
+				'comment':PORTABLE_STRING('')}
 			for arg in it.args:
 				if isinstance(arg,Const):
-					args[translate_args[acnt]] = arg.value
+					args[translate_args[acnt]] = portable_string(arg.value,encoding)
 				acnt+=1
 			for kwarg in it.kwargs:
-				args[kwarg.key] = kwarg.value.value
+				args[kwarg.key] = portable_string(kwarg.value.value,encoding)
 			update_transdict(args['context'],args['source'],fname,it.node.lineno,args['comment'])
+			transcnt += 1
+	print(u'Found %d translations' % transcnt)
 
-flist = os.listdir('templates')
-for fname in flist:
-	m = re.match('^([^\.]+)\.jinja$',fname)
-	if m:
-		parse_jinja_template(m.groups()[0])
-
-flist = os.listdir('subhandlers')
-for fname in flist:
-	m = re.match('^([^\.]+)\.py$',fname)
-	if m:
-		parse_subhandler(m.groups()[0])
+def parse_js(jsfpath):
+	sys.stdout.write(u"Parsing: %s... " % jsfpath)
+	def parse_string_arg(node):
+		if isinstance(node,jsast.String):
+			m = rx_rmquotes.match(node.value)
+			if m:
+				return m.groups()[0]
+			return u''
+		if isinstance(node,jsast.BinOp):
+			left = parse_string_arg(node.left)
+			right = parse_string_arg(node.right)
+			return left+right
 
+	def_context = u'js_%s' % os.path.splitext(os.path.basename(jsfpath))[0]
+	f = open(jsfpath,'rb')
+	jsdata = PORTABLE_STRING(f.read(),'utf-8')
+	f.close()
+	
+	transcnt = 0
+	tree = parser.parse(jsdata)
+	for node in nodevisitor.visit(tree):
+		pnames = ['source','context','comment']
+		if isinstance(node,jsast.FunctionCall):
+			ival = getattr(node.identifier,'value','')
+			if ival in [u'pysite_tr',u'pysite_tr_common',u'pysite_translate']:
+				args = []
+				for arg in node.children()[1:]:
+					args += [parse_string_arg(arg)]
+				if len(args)==0:
+					print("No arguments - skipping")
+				comment = u''
+				context = def_context
+				if node.identifier.value=='pysite_tr':
+					source = args[0]
+					if len(args)>1:
+						comment = args[1]
+				elif node.identifier.value=='pysite_tr_common':
+					context = u'js_common'
+					source = args[0]
+					if len(args)>1:
+						comment = args[1]
+				elif node.identifier.value=='pysite_translate':
+					source = args[0]
+					if len(args)==3:
+						context = args[1]
+						comment = args[2]
+					elif len(args)==2:
+						context = args[1]
+					if context.find(u'js_')!=0:
+						context = u'js_%s' % context
+				update_transdict(context,source,jsfpath,1,comment)
+				transcnt += 1
+	print(u'Found %d translations' % transcnt)
 
 def parse_ts(ts_fname):
 	doc = minidom.parse(open(ts_fname))
@@ -139,7 +203,6 @@ def rebuild_ts(ts_dict,language,filename_pathprefix):
 	ts = doc.createElement('TS')
 	ts.setAttribute('version','2.0')
 	ts.setAttribute('language',language)
-	print([type(language),language])
 	doc.appendChild(ts)
 	for context,sources in global_transdict.items():
 		context_elem = doc.createElement('context')
@@ -151,11 +214,11 @@ def rebuild_ts(ts_dict,language,filename_pathprefix):
 			for comment in v:
 				msg_elem = doc.createElement('message')
 				loc_elem = doc.createElement('location')
-				loc_elem.setAttribute('filename',os.path.join(filename_pathprefix,global_first_located[context][k][comment][0]))
+				filename = os.path.join(filename_pathprefix,global_first_located[context][k][comment][0])
+				loc_elem.setAttribute('filename',filename)
 				loc_elem.setAttribute('line',global_first_located[context][k][comment][1])
 				msg_elem.appendChild(loc_elem)
 				src_elem = doc.createElement('source')
-				print([type(k),k])
 				src_elem.appendChild(doc.createTextNode(k))
 				msg_elem.appendChild(src_elem)
 				if comment:
@@ -205,6 +268,23 @@ def rebuild_ts(ts_dict,language,filename_pathprefix):
 						ctx_elem.appendChild(msg_elem)
 	return doc.toxml(encoding='utf-8')
 
+flist = os.listdir('templates')
+for fname in flist:
+	m = re.match('^([^\.]+)\.jinja$',fname)
+	if m:
+		parse_jinja_template(m.groups()[0])
+
+flist = os.listdir('subhandlers')
+for fname in flist:
+	m = re.match('^([^\.]+)\.py$',fname)
+	if m:
+		parse_subhandler(m.groups()[0])
+
+for bdir,dirs,files in os.walk('static'):
+	for fname in files:
+		if fname.endswith('.js') and not fname=='pysite.js':
+			parse_js(os.path.join(bdir,fname))
+
 def lupdate(ts_fname,language):
 	ts_dict = {}
 	filename_pathprefix = relpath('.',dirname(ts_fname))
@@ -222,4 +302,5 @@ if __name__=='__main__':
 		sys.stderr.write("usage: %s <ts-file> <lang-code>\n" % sys.argv[0])
 		sys.stderr.write("Example: %s admin_da.ts da_DK\n" % sys.argv[0])
 		sys.exit(1)
+
 	lupdate(sys.argv[1],sys.argv[2])
