@@ -106,6 +106,13 @@ class PySiteApplication(object):
 		self.subhandlers_dir = join(basedir,'subhandlers')
 		self.translations_dir = join(basedir,'translations')
 		sys.path.append(basedir)
+		epaths = getattr(self.conf,'extrapaths',[])
+		for p in epaths:
+			if type(p) in [PORTABLE_BYTES,PORTABLE_STRING]:
+				ap = abspath(normpath(p))
+				if exists(ap):
+					print("Appending %s"%ap)
+					sys.path.append(ap)
 		self.rx_static_file = re.compile('.+\.(%s)$' % '|'.join(ext_map_content_type.keys()),re.I)
 	
 	def __call__(self,environ, start_response):
@@ -199,15 +206,11 @@ class PySiteApplication(object):
 				'sitename': self.conf.sitename,
 				'sitetitle': self.conf.sitetitle
 			}
-			template_info['supported_countries'] = [
-				{'short': 'dk', 'title': PORTABLE_STRING('Danmark')},
-				{'short': 'se', 'title': PORTABLE_STRING('Sverige')},
-				{'short': 'no', 'title': PORTABLE_STRING('Norge')}
-			]
-			template_info.update(locales.tr(lang,'common',disambiguation='school'))
-			template_info.update(locales.tr(lang,template,disambiguation='school'))
-			template_info['tr_common'].update(locales.tr(lang,'common',disambiguation='school'))
-			template_info['tr'].update(locales.tr(lang,template,disambiguation='school'))
+			template_info.update(locales.tr(lang,'common'))
+			template_info.update(locales.tr(lang,template))
+			template_info['tr_common'].update(locales.tr(lang,'common'))
+			template_info['tr'].update(locales.tr(lang,template))
+			template_info['lang'] = lang
 			
 			# Request translator
 			def translate(source,context=template,comment=None,lang=lang,locales=locales):
